@@ -4,12 +4,12 @@ use 5.008_001;
 use strict;
 #use warnings;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 use Exporter qw(import);
 
 our $TESTING_PERL_ONLY;
-$TESTING_PERL_ONLY = $ENV{DATA_UTIL_PUREPERL}
+$TESTING_PERL_ONLY = $ENV{DATA_UTIL_PUREPERL} ? 1 : 0
 	unless defined $TESTING_PERL_ONLY;
 
 unless($TESTING_PERL_ONLY){
@@ -24,8 +24,7 @@ unless($TESTING_PERL_ONLY){
 #		warn $@;
 #	}
 }
-
-require q{Data/Util/PurePerl.pm} # not to create the namespace
+require 'Data/Util/PurePerl.pm' # not to create the namespace
 	if $TESTING_PERL_ONLY;
 
 our @EXPORT_OK = qw(
@@ -43,6 +42,7 @@ our @EXPORT_OK = qw(
 	install_subroutine
 	uninstall_subroutine
 	get_code_info
+	get_code_ref
 
 	curry
 	modify_subroutine
@@ -77,7 +77,7 @@ Data::Util - A selection of utilities for data and data types
 
 =head1 VERSION
 
-This document describes Data::Util version 0.43
+This document describes Data::Util version 0.44
 
 =head1 SYNOPSIS
 
@@ -125,7 +125,8 @@ This document describes Data::Util version 0.43
 	print Foo::hello(); # Hello!
 
 	my($pkg, $name) = get_code_info(\&Foo::hello); # => ('Foo', 'hello')
-	my $fqn         = get_code_info(\&Foo::hello); # => 'Foo::bar'
+	my $fqn         = get_code_info(\&Foo::hello); # =>  'Foo::hello'
+	my $code        = get_code_ref($fqn);          # => \&Foo::hello
 
 	uninstall_subroutine('Foo', qw(hello goodby));
 
@@ -141,6 +142,8 @@ including functions for subroutines.
 The implementation of this module is both Pure Perl and XS, so if you have a C
 compiler, all the functions this module provides are really faster.
 
+There are many benchmakrs in F<DIST-DIR/benchmark/> directory.
+
 =head1 INTERFACE
 
 =head2 Check functions
@@ -174,7 +177,7 @@ For a GLOB reference.
 
 =item is_regex_ref(value)
 
-For a regular expression reference made by the C<qr//> operator.
+For a regular expression reference generated by the C<qr//> operator.
 
 =item is_instance(value, class)
 
@@ -319,9 +322,20 @@ Installs I<subr> into I<package> as I<name>.
 
 It is similar to
 C<< do{ no strict 'refs'; *{$package.'::'.$name} = \&subr; } >>.
-In addition, if I<subr> is an anonymous subroutine, it is relocated into
+In addition, if I<subr> is an anonymous subroutine, it is located into
 I<package> as a named subroutine I<&package::name>.
 
+For example:
+
+	install_subroutine($pkg,   say => sub{ print @_, "\n" });
+	install_subroutine($pkg,
+		one => \&_one,
+		two => \&_two,
+	);
+
+	# accepts a HASH reference
+	install_subroutine($pkg, { say => sub{ print @_, "\n" }); # 
+
 To re-install I<subr>, use C<< no warnings 'redefine' >> directive:
 
 	no warnings 'redefine';
@@ -334,17 +348,43 @@ Uninstalls I<names> from I<package>.
 It is similar to C<Sub::Delete::delete_sub()>, but uninstall multiple
 subroutines at a time.
 
-=item uninstall_subroutine(package, name => subr [, ...])
+If you want to specify deleted subroutines, you can supply 
+C<< name => \&subr >> pairs.
 
-Uninstalls I<name> from I<package> if the entity of I<name> is really I<subr>.
+For example:
+
+	uninstall_subroutine('Foo', 'hello');
+
+	uninstall_subroutine('Foo', hello => \&Bar::hello);
+
+	uninstall_subroutine($pkg,
+		one => \&_one,
+		two => \&_two,
+	);
+
+	# accepts a HASH reference
+	uninstall_subroutine(\$pkg, { hello => \&Bar::hello });
 
 =item get_code_info(subr)
 
 Returns a pair of elements, the package name and the subroutine name of I<subr>.
 
-It is similar to C<Sub::Identify::get_code_info()>, but it returns the full
+It is similar to C<Sub::Identify::get_code_info()>, but it returns the fully
 qualified name in scalar context.
 
+=item get_code_ref(package, name, flag?)
+
+Returns I<&package::name> if it exists, not touching the symbol in the stash.
+
+if I<flag> is a string C<-create>, it returns I<&package::name> regardles of
+its existance. That is, it is equivalent to
+C<< do{ no strict 'refs'; \&{package . '::' . $name} } >>.
+
+For example:
+
+	$code = get_code_ref($pkg, $name);          # like  *{$pkg.'::'.$name}{CODE}
+	$code = get_code_ref($pkg, $name, -create); # like \&{$pkg.'::'.$name}
+
 =item curry(subr, args and/or placeholders)
 
 Makes I<subr> curried and returns the curried subroutine.
@@ -377,7 +417,7 @@ Returns whether I<subr> is a modified subroutine.
 
 Gets I<property> from I<modified>.
 
-Valid properties are: C<before>, C<around>, C<after> and C<original>.
+Valid properties are: C<before>, C<around>, C<after>.
 
 =item subroutine_modifier(modified_subr, modifier => [subroutine(s)])
 
